Enum amazon_sp_shipping::models::service_type::ServiceType
source · [−]pub enum ServiceType {
Ground,
Standard,
Premium,
}Expand description
ServiceType : The type of shipping service that will be used for the service offering. The type of shipping service that will be used for the service offering.
Variants
Ground
Standard
Premium